<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/** 
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsAboutBrand extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-about-brand';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'About - The Brand', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-text';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'aboutbrand', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_about_brand',
			[
				'label' => esc_html__( 'About Brand', 'bdevs-elementor' ),
			]
		);	
		$this->add_control(
			'section_heading',
			[
				'label'       => __( 'Section Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your section heading', 'bdevs-elementor' ),
				'default'     => __( 'Enter your section heading', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'section_header',
			[
				'label'       => __( 'Section Header', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your section header', 'bdevs-elementor' ),
				'default'     => __( 'Enter your section header', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
		$this->add_control(
			'section_text',
			[
				'label'       => __( 'Section Text', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your section text', 'bdevs-elementor' ),
				'default'     => __( 'Enter your section text', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
        $this->add_control(
            'button_link',
            [
                'label'       => __( 'Button Link', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Button Link', 'bdevs-elementor' ),
                'default'     => __( 'https://www.youtube.com/watch?v=3S9rxiz1lsU', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'button_text',
            [
                'label'       => __( 'Text Button', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Text Button', 'bdevs-elementor' ),
                'default'     => __( 'watch video', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );

	
	

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_section_heading',
			[
				'label'   => esc_html__( 'Show Section Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			
		$this->add_control(
			'show_section_header',
			[
				'label'   => esc_html__( 'Show Section Header', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_section_text',
			[
				'label'   => esc_html__( 'Show Section Text', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_text_button',
			[
				'label'   => esc_html__( 'Show Text Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
	

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>  

<div class="page-wrapper">
    <section class="bg-1">
        <div class="container inner-spacer">
            <?php if (( '' !== $settings['section_heading'] ) && ( $settings['show_section_heading'] )): ?>
            <div class="inner-divider"></div>
            <div class="row">
                <div class="col-lg-12">
                    <h2 class="section-heading">
                        <?php echo wp_kses_post($settings['section_heading']); ?>
                    </h2>
                </div>
            </div>
        	<?php endif; ?>
            <div class="inner-divider-half"></div>
            <div class="row">
                <div class="col-lg-12">
                	<?php if (( '' !== $settings['section_header'] ) && ( $settings['show_section_header'] )): ?>
                    <h1 class="section-header">
                    	<?php echo wp_kses_post($settings['section_header']); ?>
                    </h1>
                    <div class="inner-divider-half"></div>
                    <?php endif; ?>
                    <?php if (( '' !== $settings['section_text'] ) && ( $settings['show_section_text'] )): ?>
                    <div class="section-txt">
                        <p><?php echo wp_kses_post($settings['section_text']); ?></p>
                    </div>
                    <div class="inner-divider-half"></div>
                    <?php endif; ?>
                    <?php if (( '' !== $settings['button_text'] ) && ( $settings['show_text_button'] )): ?>
                    <div class="button-the-wrapper button-the-wrapper-light button-the-wrapper-all">
                        <a class="button-the button-the-light" data-lity="" href="<?php echo wp_kses_post($settings['button_link']); ?>"><?php echo wp_kses_post($settings['button_text']); ?></a>
                    </div>
                    <div class="inner-divider-half"></div>
                    <?php endif; ?>
                </div>
            </div>
            <div class="inner-divider-half"></div>
        </div>
    </section>
</div>
<?php
}
}