<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/** 
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsBlogWrapper2 extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-blog-wrapper-2';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Blog - Blog Wrapper 2', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-slider';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'blogwrapper2', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_blog_wrapper_2',
			[
				'label' => esc_html__( 'Blog Wrapper 2', 'bdevs-elementor' ),
			]
		);	
		$this->add_control(
			'section_heading',
			[
				'label'       => __( 'Section Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your section heading', 'bdevs-elementor' ),
				'default'     => __( 'Enter your section heading', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'section_header',
			[
				'label'       => __( 'Section Header', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your section header', 'bdevs-elementor' ),
				'default'     => __( 'Enter your section header', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
		$this->add_control(
            'post_number',
            [
                'label'       => __( 'Post Number', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Post Number', 'bdevs-elementor' ),
                'default'     => __( '4', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'post_order',
            [
                'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
                    'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
                ],
                'default'   => 'asc',
            ]
        );
        $this->add_control(
            'post_orderby',
            [
                'label'     => esc_html__( 'Post Orderby', 'bdevs-elementor' ),
                'type'      => Controls_Manager::TEXT,
                'placeholder' => __( 'Post Orderby', 'bdevs-elementor' ),
                'default'     => __( 'ID', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'text_button',
            [
                'label'       => __( 'Text Button', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Text Button', 'bdevs-elementor' ),
                'default'     => __( 'Read more', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );

	
	

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_section_heading',
			[
				'label'   => esc_html__( 'Show Section Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			
		$this->add_control(
			'show_section_header',
			[
				'label'   => esc_html__( 'Show Section Header', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_text_button',
			[
				'label'   => esc_html__( 'Show Text Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
	

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>  

<div class="page-wrapper">
    <section class="bg-3">
        <div class="container inner-spacer">
            <div class="inner-divider"></div>
            <?php if (( '' !== $settings['section_heading'] ) && ( $settings['show_section_heading'] )): ?>
            <div class="row">
                <div class="col-lg-12">
                    <h2 class="section-heading section-heading-dark">
                    	<?php echo wp_kses_post($settings['section_heading']); ?>
                    </h2>
                </div>
            </div>
        	<?php endif; ?>
        	<?php if (( '' !== $settings['section_heading'] ) && ( $settings['show_section_heading'] ) && ('' !== $settings['section_header'] ) && ( $settings['show_section_header'] )): ?>
            <div class="inner-divider-half"></div>
        	<?php endif; ?>
            <?php if (( '' !== $settings['section_header'] ) && ( $settings['show_section_header'] )): ?>
            <div class="row">
                <div class="col-lg-12">
                    <h1 class="section-header section-header-dark">
                    	<?php echo wp_kses_post($settings['section_header']); ?>
                    </h1>
                </div>
            </div>
        	<?php endif; ?>
            <div class="inner-divider"></div>
        </div>
    </section>
    <section class="bg-3">
        <div class="container-fluid nopadding">
            <div class="extra-margin-owl">
                <div class="carousel-item-img-wrapper carousel-item-img-wrapper-all">
                    <div class="owl-carousel" id="owl-carousel-all">
                        <?php  
                        $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'post',  'orderby' => $post_orderby, 'order' => $post_order));
                            $i=0;
                            while($wp_query->have_posts()): $wp_query->the_post();
                                $i++;
                        ?>
                        <div class="post-box">
                            <div class="carousel-item-all carousel-item-works-00<?php echo esc_attr($i); ?>" style="background-image: url(<?php the_post_thumbnail_url();?>);"></div>
                            <div class="post-box-inner">
                                <div class="inner-divider-50"></div>
                                <h4 class="post-heading post-heading-all post-heading-all-lead post-heading-inner">
                                    <?php the_title(); ?>
                                </h4>
                                <span class="date"><?php the_time(get_option( 'date_format' ));?></span>
                                <?php if (( '' !== $settings['text_button'] ) && ( $settings['show_text_button'] )): ?>
                                <div class="inner-divider-50"></div>
                                <div class="button-the-wrapper">
                                    <a class="button-the" href="<?php the_permalink(); ?>"><?php echo wp_kses_post($settings['text_button']); ?></a>
                                </div>
                            	<?php endif; ?>
                            </div>
                        </div>
                        <?php endwhile; ?>
                    </div>
                </div>
            </div>
            <div class="inner-divider-50"></div>
            <div class="owl-nav owl-nav-custom-all owl-nav-custom-news"></div>
            <div class="inner-divider-50"></div>
        </div>
    </section>
</div>

<?php if (is_admin()) { ?>
<script type="text/javascript">
   $("#owl-carousel-all").owlCarousel({
        loop: false,
        center: false,
        autoplay: false,
        autoplaySpeed: 1000,
        autoplayTimeout: 5000,
        smartSpeed: 450,
        nav: false,
        nav: true,
        navText: ["<i class='ion-chevron-left'></i>", "<i class='ion-chevron-right'></i>"],
        navContainer: '.owl-nav-custom-all',
        responsive: {
            0: {
                items: 1,
                margin: 30
            },
            768: {
                items: 2,
        margin: 50
            },
            980: {
                items: 2,
        margin: 50
            },
            1240: {
                items: 3,
                margin: 50
            }
        }
    });
</script>
<?php }  ?>
<?php
}
}