<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/** 
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsContactInfo extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-contact-info';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Contact - The Info', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-info';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'contactinfo', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_contact_info',
			[
				'label' => esc_html__( 'Contact Info', 'bdevs-elementor' ),
			]
		);	
		$this->add_control(
			'section_heading',
			[
				'label'       => __( 'Section Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your section heading', 'bdevs-elementor' ),
				'default'     => __( 'Enter your section heading', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'section_header',
			[
				'label'       => __( 'Section Header', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your section header', 'bdevs-elementor' ),
				'default'     => __( 'Enter your section header', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
        $this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'About The Services Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Slide #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [
					[
						'name'        => 'item_heading',
						'label'       => esc_html__( 'Item Heading', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Item Heading' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'item_header',
						'label'       => esc_html__( 'Item Header', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Item Header' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

	
	

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_section_heading',
			[
				'label'   => esc_html__( 'Show Section Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			
		$this->add_control(
			'show_section_header',
			[
				'label'   => esc_html__( 'Show Section Header', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
	

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>  

<div class="page-wrapper">
    <section class="bg-1">
        <div class="container inner-spacer">
            <div class="inner-divider"></div>
            <?php if (( '' !== $settings['section_heading'] ) && ( $settings['show_section_heading'] )): ?>
            <div class="row">
                <div class="col-lg-12">
                    <h2 class="section-heading">
                        <?php echo wp_kses_post($settings['section_heading']); ?>
                    </h2>
                </div>
            </div>
        	<?php endif; ?>
            <?php if (( '' !== $settings['section_heading'] ) && ( $settings['show_section_heading'] ) && ( '' !== $settings['section_header'] ) && ( $settings['show_section_header'] )): ?>
            <div class="inner-divider-half"></div>
        	<?php endif; ?>
            <?php if (( '' !== $settings['section_header'] ) && ( $settings['show_section_header'] )): ?>
            <div class="row">
                <div class="col-lg-12">
                    <h1 class="section-header">
                        <?php echo wp_kses_post($settings['section_header']); ?>
                    </h1>
                </div>
            </div>
            <?php endif; ?>
            <div class="inner-divider-half"></div>
            <div class="row">
            	<?php 
				foreach ( $settings['tabs'] as $item ) : 
				?>
                <div class="inner-divider-half mobile-visible"></div>
                <div class="col-md-4">
                    <h2 class="section-subheading">
                        <?php echo wp_kses_post($item['item_heading']); ?>
                    </h2>
                    <div class="inner-divider-50"></div>
                    <?php echo wp_kses_post($item['item_header']); ?>
                </div>
            <?php endforeach; ?>
            </div>
            <div class="inner-divider"></div>
        </div>
    </section>
</div>
<?php
}
}