<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/** 
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsHeroCarouselSlider extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-hero-carousel-slider';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Home 2 - Hero Carousel Slider', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-slider-device';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'herocarouselslider', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_hero_carousel_slider',
			[
				'label' => esc_html__( 'Hero Carousel Slider', 'bdevs-elementor' ),
			]
		);	
		$this->add_control(
            'post_number',
            [
                'label'       => __( 'Project Number', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Project Number', 'bdevs-elementor' ),
                'default'     => __( '4', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'post_order',
            [
                'label'     => esc_html__( 'Project Order', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
                    'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
                ],
                'default'   => 'asc',
            ]
        );
        $this->add_control(
            'post_orderby',
            [
                'label'     => esc_html__( 'Project Orderby', 'bdevs-elementor' ),
                'type'      => Controls_Manager::TEXT,
                'placeholder' => __( 'Project Orderby', 'bdevs-elementor' ),
                'default'     => __( 'ID', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );	
		$this->add_control(
			'text_button',
			[
				'label'       => __( 'Text Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your text button', 'bdevs-elementor' ),
				'default'     => __( 'view project', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
		$this->add_control(
			'link_twitter',
			[
				'label'       => __( 'Link Twitter', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your link twitter', 'bdevs-elementor' ),
				'default'     => __( 'https://twitter.com/', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
		$this->add_control(
			'link_facebook',
			[
				'label'       => __( 'Link Facebook', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your link facebook', 'bdevs-elementor' ),
				'default'     => __( 'https://www.facebook.com/', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
		$this->add_control(
			'link_instagram',
			[
				'label'       => __( 'Link Instagram', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your link instagram', 'bdevs-elementor' ),
				'default'     => __( 'https://www.instagram.com/', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
		$this->add_control(
			'bottom_credits',
			[
				'label'       => __( 'Text Bottom Credits', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your text bottom credits', 'bdevs-elementor' ),
				'default'     => __( 'Fightex © All Rights Reserved', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
	
	

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_text_button',
			[
				'label'   => esc_html__( 'Show Text Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_link_twitter',
			[
				'label'   => esc_html__( 'Show Link Twitter', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			
		$this->add_control(
			'show_link_facebook',
			[
				'label'   => esc_html__( 'Show Link Facebook', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_link_instagram',
			[
				'label'   => esc_html__( 'Show Link Instagram', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_bottom_credits',
			[
				'label'   => esc_html__( 'Show Text Bottom Credits', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
	
		$this->end_controls_section();
	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>  

<div class="hero-fullscreen">
    <div class="hero-fullscreen-FIX">
        <div class="hero-bg">
            <div class="swiper-container-wrapper">
                <div class="swiper-container">
                    <div class="swiper-wrapper">
                    	<?php  
					    $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'project',  'orderby' => $post_orderby, 'order' => $post_order));
					        $i=0;
					        while($wp_query->have_posts()): $wp_query->the_post();
					        	$project_img_home = get_post_meta(get_the_ID(),'_cmb_project_image_home',true);
					        	$i++;
					    ?>
                        <div class="swiper-slide">
                            <div class="swiper-slide-inner">
                                <div class="swiper-slide-inner-bg-2 bg-img-<?php echo esc_attr($i);?>" style="background-image: url(<?php echo wp_get_attachment_url($project_img_home);?>);"></div>
                                <div class="gradient-overlay-home"></div>
                                <div class="swiper-slide-inner-txt-2">
                                    <h1 class="main-title">
                                        <?php the_title(); ?>
                                    </h1>
                                    <?php if (('' !== $settings['text_button'] ) && ( $settings['show_text_button'] )): ?>
                                    <div class="inner-divider-ultra-half"></div>
                                    <div class="button-the-wrapper button-the-wrapper-light">
                                        <a class="button-the button-the-light" href="<?php the_permalink(); ?>"><?php echo wp_kses_post($settings['text_button']); ?></a>
                                    </div>
                                    <?php endif ?>
                                </div>
                            </div>
                        </div>
                    	<?php endwhile; ?>
                    </div>
                </div>
            </div>
            <div class="border-top"></div>
            <div class="border-left"></div>
            <div class="border-left border-left-color"></div>
            <div class="border-right-color"></div>
            <div class="border-right-color border-right"></div>
            <div class="border-bottom"></div>
            <div class="border-bottom border-bottom-color"></div>

            <div class="social-icons-home">
                <ul>
                    <?php if (('' !== $settings['link_twitter'] ) && ( $settings['show_link_twitter'] )): ?>
                    <li>
                        <a class="ion-social-twitter" href="<?php echo wp_kses_post($settings['link_twitter']); ?>"><span><?php echo esc_html__( 'Twitter', 'fightex' );?></span></a>
                    </li>
                	<?php endif; ?>
                	<?php if (('' !== $settings['link_facebook'] ) && ( $settings['show_link_facebook'] )): ?>
                    <li>
                        <a class="ion-social-facebook" href="<?php echo wp_kses_post($settings['link_facebook']); ?>"><span><?php echo esc_html__( 'Facebook', 'fightex' );?></span></a>
                    </li>
                    <?php endif; ?>
                	<?php if (('' !== $settings['link_instagram'] ) && ( $settings['show_link_instagram'] )): ?>
                    <li>
                        <a class="ion-social-instagram" href="<?php echo wp_kses_post($settings['link_instagram']); ?>"><span><?php echo esc_html__( 'Instagram', 'fightex' );?></span></a>
                    </li>
                	<?php endif; ?>
                </ul>
            </div>
            <?php if (('' !== $settings['bottom_credits'] ) && ( $settings['show_bottom_credits'] )): ?>
            <div class="bottom-credits">
                <?php echo wp_kses_post($settings['bottom_credits']); ?>
            </div>
            <?php endif; ?>
            <div class="hero-slider-bg-controls">
                <div class="swiper-slide-controls swiper-slide-controls-dark slide-prev">
                    <div class="ion-ios-arrow-left"></div>
                </div>
                <div class="swiper-slide-controls slide-next">
                    <div class="ion-ios-arrow-right"></div>
                </div>
            </div>
            <div class="swiper-slide-pagination"></div>
            <div class="swiper-slide-controls-play-pause-wrapper swiper-slide-controls-play-pause slider-on-off">
                <div class="slider-on-off-switch">
                    <i class="ion-ios-play"></i>
                </div> 
                <div class="slider-progress-bar">
                    <span>
                        <svg class="circle-svg" height="50" width="50">
                            <circle class="circle" cx="25" cy="25" fill="none" r="24" stroke="#ffffff" stroke-width="2"></circle>
                        </svg>
                    </span>
                </div>
            </div>
        </div>
    </div>
</div>
<?php if (is_admin()) { ?>
<script type="text/javascript">
   $(function () {
    "use strict";


    setTimeout(function () {
        // 1. preloader
        $("#preloader").fadeOut(1200);
        $(".preloader-bg").delay(1000).fadeOut(1200);
        swiper.init();
    }, 2000);

    // 2. navigation
    $(".navbar-collapse ul li a.nav-close").on("click", function () {
        $(".navbar-toggle:visible").click();
    });

    // 3. swiper slider
    var swiper = new Swiper(".swiper-container-wrapper .swiper-container", {
        preloadImages: false,
        autoplay: {
            delay: 4000,
            disableOnInteraction: false
        },
        init: false,
        loop: true,
        speed: 1200,
        grabCursor: true,
        mousewheel: {
            enable: true
        },
        keyboard: true,
        simulateTouch: true,
        parallax: true,
        effect: "slide",
        pagination: {
            el: ".swiper-slide-pagination",
            clickable: true
        },
        navigation: {
            nextEl: ".slide-next",
            prevEl: ".slide-prev"
        },
    centeredSlides: true,
        slidesPerView: 2,
        spaceBetween: 0,
        breakpoints: {
            768: {
                slidesPerView: 1,
                spaceBetween: 0
            }
        }
    });
    swiper.on("slideChangeTransitionStart", function () {
        $(".slider-progress-bar").removeClass("slider-active");
    });
    swiper.on("slideChangeTransitionEnd", function () {
        $(".slider-progress-bar").addClass("slider-active");
    });
    var playButton = $(".swiper-slide-controls-play-pause-wrapper");
    function autoEnd() {
        playButton.removeClass("slider-on-off");
        swiper.autoplay.stop();
    }
    function autoStart() {
        playButton.addClass("slider-on-off");
        swiper.autoplay.start();
    }
    playButton.on("click", function () {
        if (playButton.hasClass("slider-on-off")) autoEnd();
        else autoStart();
        return false;
    });
  
  // 4. dropdown
  $(".dropdown-toggle").on("click", function(e) {
      if ($(document).width() > 768) {
          e.preventDefault();
          var url = $(this).attr('href');
          if (url !== '#') {
              window.location.href = url;
          }
      }
  });


});
</script>
<?php }  ?>
<?php
}
}