<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/** 
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsYoutubeVideoBackground extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-youtube-video-background';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Home 4 - Youtube Video Background', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-slider-video';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'youtubevideobackground', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_youtube_video_background',
			[
				'label' => esc_html__( 'Youtube Video Background', 'bdevs-elementor' ),
			]
		);
		$this->add_control(
			'link_video_youtube',
			[
				'label'       => __( 'Link Youtube Video', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your link youtube video Ex:https://www.youtube.com/watch?v=3S9rxiz1lsU', 'bdevs-elementor' ),
				'default'     => __( '3S9rxiz1lsU', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'title',
			[
				'label'       => __( 'Text Title', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your text title', 'bdevs-elementor' ),
				'default'     => __( 'Simplicity is <br>not a style', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
		$this->add_control(
			'link_button',
			[
				'label'       => __( 'Link Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your link button', 'bdevs-elementor' ),
				'default'     => __( '#', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
		$this->add_control(
			'text_button',
			[
				'label'       => __( 'Text Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your text button', 'bdevs-elementor' ),
				'default'     => __( 'view project', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
		$this->add_control(
			'link_twitter',
			[
				'label'       => __( 'Link Twitter', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your link twitter', 'bdevs-elementor' ),
				'default'     => __( 'https://twitter.com/', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
		$this->add_control(
			'link_facebook',
			[
				'label'       => __( 'Link Facebook', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your link facebook', 'bdevs-elementor' ),
				'default'     => __( 'https://www.facebook.com/', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
		$this->add_control(
			'link_instagram',
			[
				'label'       => __( 'Link Instagram', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your link instagram', 'bdevs-elementor' ),
				'default'     => __( 'https://www.instagram.com/', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
		$this->add_control(
			'bottom_credits',
			[
				'label'       => __( 'Text Bottom Credits', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your text bottom credits', 'bdevs-elementor' ),
				'default'     => __( 'Fightex © All Rights Reserved', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
	
	

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_video_background',
			[
				'label'   => esc_html__( 'Show Video Background', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_title',
			[
				'label'   => esc_html__( 'Show Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_text_button',
			[
				'label'   => esc_html__( 'Show Text Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_link_twitter',
			[
				'label'   => esc_html__( 'Show Link Twitter', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			
		$this->add_control(
			'show_link_facebook',
			[
				'label'   => esc_html__( 'Show Link Facebook', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_link_instagram',
			[
				'label'   => esc_html__( 'Show Link Instagram', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_bottom_credits',
			[
				'label'   => esc_html__( 'Show Text Bottom Credits', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
	
		$this->end_controls_section();
	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>  

<div class="home-page" id="home">
    <div class="hero-fullscreen">
       	<?php if (('' !== $settings['link_video_youtube'] ) && ( $settings['show_video_background'] )): ?>
        <div class="hero-bg hero-fullscreen-FIX">
            <div id="videoContainment">
                <div class="player" data-property=
                    "{videoURL: '<?php echo wp_kses_post($settings['link_video_youtube']); ?>', containment: '#videoContainment', showControls: false, autoPlay: true, loop: true, vol: 50, mute: true, startAt: 0, stopAt: 0, opacity: 1, addRaster: false, quality: 'large', optimizeDisplay: true, ratio: 16/9}"
                    id="bgndVideo"></div>
            </div>
            <div class="YT-bg"></div>
        </div>
        <?php endif; ?>
    </div>
    <div class="gradient-overlay-home"></div>
    <?php if (('' !== $settings['title'] ) && ( $settings['show_title'] )): ?>
    <div class="swiper-slide-inner-txt-all">
        <h1 class="main-title">
            <?php echo wp_kses_post($settings['title']); ?>
        </h1>
        <?php if (('' !== $settings['text_button'] ) && ( $settings['show_text_button'] )): ?>
        <div class="inner-divider-ultra-half"></div>
        <div class="button-the-wrapper button-the-wrapper-light">
            <a class="button-the button-the-light" href="<?php echo wp_kses_post($settings['link_button']); ?>"><?php echo wp_kses_post($settings['text_button']); ?></a>
        </div>
    	<?php endif; ?>
    </div>
	<?php endif; ?>
</div>
<div class="border-top"></div>
<div class="border-left"></div>
<div class="border-left border-left-color"></div>
<div class="border-right-color"></div>
<div class="border-right-color border-right"></div>
<div class="border-bottom"></div>
<div class="border-bottom border-bottom-color"></div>
<div class="social-icons-home">
    <ul>
	    <?php if (('' !== $settings['link_twitter'] ) && ( $settings['show_link_twitter'] )): ?>
	    <li>
	        <a class="ion-social-twitter" href="<?php echo wp_kses_post($settings['link_twitter']); ?>"><span><?php echo esc_html__( 'Twitter', 'fightex' );?></span></a>
	    </li>
		<?php endif; ?>
		<?php if (('' !== $settings['link_facebook'] ) && ( $settings['show_link_facebook'] )): ?>
	    <li>
	        <a class="ion-social-facebook" href="<?php echo wp_kses_post($settings['link_facebook']); ?>"><span><?php echo esc_html__( 'Facebook', 'fightex' );?></span></a>
	    </li>
	    <?php endif; ?>
		<?php if (('' !== $settings['link_instagram'] ) && ( $settings['show_link_instagram'] )): ?>
	    <li>
	        <a class="ion-social-instagram" href="<?php echo wp_kses_post($settings['link_instagram']); ?>"><span><?php echo esc_html__( 'Instagram', 'fightex' );?></span></a>
	    </li>
		<?php endif; ?>
	</ul>
</div>
<?php if (('' !== $settings['bottom_credits'] ) && ( $settings['show_bottom_credits'] )): ?>
<div class="bottom-credits">
    <?php echo wp_kses_post($settings['bottom_credits']); ?>
</div>
<?php endif; ?>

<?php if (is_admin()) { ?>
<script type="text/javascript">
   $("#bgndVideo").YTPlayer();
</script>
<?php }  ?>
<?php
}
}