<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/** 
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsWorksWrapper1 extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-works-wrapper-1';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Works - Works Wrapper 1', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-slider';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'workswrapper1', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') , 
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_works_wrapper_1',
			[
				'label' => esc_html__( 'Works Wrapper 1', 'bdevs-elementor' ),
			]
		);	
		$this->add_control(
			'section_heading',
			[
				'label'       => __( 'Section Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your section heading', 'bdevs-elementor' ),
				'default'     => __( 'Enter your section heading', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);	
		$this->add_control(
			'section_header',
			[
				'label'       => __( 'Section Header', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your section header', 'bdevs-elementor' ),
				'default'     => __( 'Enter your section header', 'bdevs-elementor' ),
				'label_block' => true,
			]	
		);
		$this->add_control(
            'post_number',
            [
                'label'       => __( 'Project Number', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Project Number', 'bdevs-elementor' ),
                'default'     => __( '4', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'post_order',
            [
                'label'     => esc_html__( 'Project Order', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
                    'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
                ],
                'default'   => 'asc',
            ]
        );
        $this->add_control(
            'post_orderby',
            [
                'label'     => esc_html__( 'Project Orderby', 'bdevs-elementor' ),
                'type'      => Controls_Manager::TEXT,
                'placeholder' => __( 'Project Orderby', 'bdevs-elementor' ),
                'default'     => __( 'ID', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'text_button',
            [
                'label'       => __( 'Text Button', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Text Button', 'bdevs-elementor' ),
                'default'     => __( 'View project', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );

	
	

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_section_heading',
			[
				'label'   => esc_html__( 'Show Section Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			
		$this->add_control(
			'show_section_header',
			[
				'label'   => esc_html__( 'Show Section Header', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_text_button',
			[
				'label'   => esc_html__( 'Show Text Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
	

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>  

<div class="page-wrapper">
	<?php if (( '' !== $settings['section_heading'] ) && ( $settings['show_section_heading'] ) || ('' !== $settings['section_header'] ) && ( $settings['show_section_header'] )): ?>
    <section class="bg-1">
        <div class="container inner-spacer">
            <div class="inner-divider"></div>
            <?php if (( '' !== $settings['section_heading'] ) && ( $settings['show_section_heading'] )): ?>
            <div class="row">
                <div class="col-lg-12">
                    <h2 class="section-heading">
                        <?php echo wp_kses_post($settings['section_heading']); ?>
                    </h2>
                </div>
            </div>
            <?php endif; ?>
            <?php if (( '' !== $settings['section_heading'] ) && ( $settings['show_section_heading'] ) && ('' !== $settings['section_header'] ) && ( $settings['show_section_header'] )): ?>
            <div class="inner-divider-half"></div>
            <?php endif; ?>
            <?php if (('' !== $settings['section_header'] ) && ( $settings['show_section_header'] )): ?>
            <div class="row">
                <div class="col-lg-12">
                    <h1 class="section-header">
                        <?php echo wp_kses_post($settings['section_header']); ?>
                    </h1>
                </div>
            </div>
            <?php endif; ?>
            <div class="inner-divider"></div>
        </div>
    </section>
    <?php endif; ?>
    <?php  
    $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'project',  'orderby' => $post_orderby, 'order' => $post_order));
        while($wp_query->have_posts()): $wp_query->the_post();
            $project_content = get_post_meta(get_the_ID(),'_cmb_project_content', true);
            $project_sub = get_post_meta(get_the_ID(),'_cmb_project_subtitle', true);
            $project_img_1 = get_post_meta(get_the_ID(),'_cmb_project_image_1',true);
            $project_img_2 = get_post_meta(get_the_ID(),'_cmb_project_image_2',true);
    ?>
    <section class="bg-3">
        <div class="container inner-spacer">
            <div class="inner-divider"></div>
            <div class="row">
                <div class="col-lg-12">
                    <div class="subtitle"><?php print wp_specialchars_decode($project_sub); ?></div>
                    <div class="inner-divider-half"></div>
                    <div class="post-spacing-3">
                        <h1 class="main-title main-title-all main-title-all-left">
                            <?php the_title(); ?>
                        </h1>
                        <div class="inner-divider-half"></div>
                        <?php print wp_specialchars_decode($project_content); ?>
                        <?php if (('' !== $settings['text_button'] ) && ( $settings['show_text_button'] )): ?>
                        <div class="inner-divider-half"></div>
                        <div class="button-the-wrapper button-the-wrapper-all">
                            <a class="button-the" href="<?php the_permalink(); ?>"><?php echo wp_kses_post($settings['text_button']); ?></a>
                        </div>
                    	<?php endif ?>
                    </div>
                </div>
            </div>
            <div class="inner-divider"></div>
        </div>
    </section>
    <section class="bg-3">
        <div class="container-fluid inner-spacer">
            <div class="row">
                <div class="col-lg-12">
                    <div class="extra-margin-all">
                        <div class="showcase-bottom popup-photo-gallery">
                            <div class="showcase-bottom-img">
                                <a href="<?php echo wp_get_attachment_url($project_img_1);?>">
                                <img src="<?php echo wp_get_attachment_url($project_img_1);?>" alt="Img">
                                </a>
                            </div>
                            <div class="showcase-bottom-img">
                                <a href="<?php echo wp_get_attachment_url($project_img_2);?>">
                                <img src="<?php echo wp_get_attachment_url($project_img_2);?>" alt="Img">
                                </a>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
	<?php endwhile ?>
</div>
<?php
}
}